VAppNavigator class
兜底用的全局 Navigator 持有者(仅给非 Widget 场景)
- 拦截器踢登录
- JPush 推送跳转
- 全局异常 toast 业务代码"绝对禁止"用这个,统一走下方 BuildContext 扩展
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scaffoldMessengerKey
→ GlobalKey<
ScaffoldMessengerState> -
final
Methods
-
关闭当前页面,返回上一页(给 ViewModel/Notifier 等无 context 场景用)
result可携带返回值delta返回的页面层数,默认1;等同 Get.close(delta) - 保留当前页面,跳转到新页面(推送跳转用)
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reLaunch<
T> (Widget page) → Future< T?> - 关闭所有页面,打开到应用内的某个页面(拦截器踢登录、退登)
-
showSnackBar(
String msg) → void - 全局 toast(zone 异常处理用)
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → VAppNavigator
-
final