VRouterConfig class

路由动画配置(业务项目在 main/initApp 里设置)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

curve Curve
动画曲线
getter/setter pair
duration Duration
动画时长
getter/setter pair
enableFade bool
是否启用渐隐动画
getter/setter pair